@@ -51,13 +51,13 @@ class Partial(object):
     @property
     def output_path(self):
         return self._output_path
-        
+
     @output_path.setter
     def output_path(self, path):
         self._output_path = path
         for key in self.partial:
             self.partial[key].output_path = path
-                    
+
     def add_weight(self, trajectory=None, field=None, fluctuations=False):
         for key in self.partial:
             self.partial[key].add_weight(trajectory, field, fluctuations)
@@ -81,19 +81,22 @@ class Partial(object):
                 for j in range(len(self.species)):
                     isp = self.species[i]
                     jsp = self.species[j]
-                    if j >= i:
+                    if j >= i or not self.partial[(isp, jsp)]._symmetric:
                         self.partial[(isp, jsp)].compute()
                     else:
                         # The isp-jsp has been already calculated
                         self.partial[(isp, jsp)].grid = self.partial[(jsp, isp)].grid
                         self.partial[(isp, jsp)].value = self.partial[(jsp, isp)].value
+                        self.partial[(isp, jsp)].analysis = self.partial[(jsp, isp)].analysis
 
     def write(self):
         for partial in self.partial.values():
             partial.write()
-                        
+
     def do(self, update=False):
         if update and not self.need_update():
+            for partial in self.partial.values():
+                partial.read()
             return
 
         self.compute()
