@@ -12,25 +12,25 @@ from .helpers import setup_t_grid
 __all__ = ['CollectiveOverlap', 'SelfOverlap']
 
 
-def pairs_numpy(f, x, y, L):
+def pairs_numpy(f, x, y):
     """
     Apply function f to all pairs in x[i] and y[j] and return a numpy
     array of f values.
     """
     fxy = numpy.ndarray((len(y), len(x)))
     for i in range(fxy.shape[0]):
-        fxy[i, :] = f(x[:], y[i], L)
+        fxy[i, :] = f(x[:], y[i])
     return fxy
 
-def square_displacement(x, y, L=None):
+def square_displacement(x, y):
     """Return array of square distances (no pbc)."""
     return numpy.sum((x-y)**2, axis=1)
 
-def collective_overlap(r0, r1, side, a_square):
-    rij = pairs_numpy(square_displacement, r0, r1, side)
+def collective_overlap(r0, r1, a_square):
+    rij = pairs_numpy(square_displacement, r0, r1)
     return (rij.flatten() < a_square).sum()
 
-def self_overlap(r0, r1, side, a_square):
+def self_overlap(r0, r1, a_square):
     rij = square_displacement(r0, r1)
     return rij.flatten() < a_square
 
@@ -53,10 +53,8 @@ class CollectiveOverlap(Correlation):
         self._discrete_tgrid = setup_t_grid(self.trajectory, self.grid, offset=norigins != '1')
 
     def _compute(self):
-        side = self.trajectory.read(0).cell.side
-
         def f(x, y):
-            return collective_overlap(x, y, side, self.a_square).sum() / float(x.shape[0])
+            return collective_overlap(x, y, self.a_square).sum() / float(x.shape[0])
         self.grid, self.value = gcf_offset(f, self._discrete_tgrid,
                                            self.skip, self.trajectory.steps, self._pos)
         self.grid = [ti * self.trajectory.timestep for ti in self.grid]
@@ -80,10 +78,8 @@ class SelfOverlap(Correlation):
         self.a_square = a**2
 
     def _compute(self):
-        side = self.trajectory.read(0).cell.side
-
         def f(x, y):
-            return self_overlap(x, y, side, self.a_square).sum() / float(x.shape[0])
+            return self_overlap(x, y, self.a_square).sum() / float(x.shape[0])
         self.grid, self.value = gcf_offset(f, self._discrete_tgrid,
                                            self.skip, self.trajectory.steps, self._pos_unf)
         self.grid = [ti * self.trajectory.timestep for ti in self.grid]
